==> zither-1.1.13.tar.gz: zither_prj/zither/jpreturn.h <==
// jpreturn.h
// $Id: jpreturn.h,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
// masashi shimakura
//
//
// japanese code return file. jpreturn.h
// 
// Υեjpretun.hˤϡsitar(biwa)Фܸ᤹ʸdefineʬܤƤޤ
// ɬ EUC-JP Υ󥳡ǥ󥰤¸Ƥ
// Windows(VC++)ξϲƤޤޤǤ
// 

#ifndef _JPRETURN_H_
  #define _JPRETURN_H_
  
#define MAIL_BODY_1 "Υ֥åϥ᡼ˡưַ⡼1ꤵƤޤ \n ⤦ĥ顼Ϣ³ߤޤ \n üߤȡˤʴƻ뤬3Ϣ³ƹԤɬפޤ\n\n\n"
#define MAIL_BODY_2 "Υ֥åϥ᡼ˡưַ⡼2ꤵƤޤ \n ⤦ĥ顼Ϣ³ߤޤ \n üߤȡˤʴƻ뤬Ԥɬפޤ\n\n\n"

#define ADMIN_BODY_1 "Administratorޥzitherδѹǽޤ\r\n̵꤬Τ륤餫⤷ޤ \r\nǰΤᡢôԤ˳ǧƤߤƤ"

#define ADMIN_BODY_2 "ưѹԤޤ "

#define CLIENT_BODY_1  "ƻ륯饤ȤȤ³ޤ\r\nΰդ̵Хȥ֥βǽޤ \r\n δƻ륯饤ȤǼ¹ԤƤƻϡƼ¹ԤƤޤ "
#define CLIENT_BODY_2 "饤Ȥ³ڤޤ "

#define CLIENT_BODY_3 "zitherФ˲³sitarƻ륯饤Ȥ³򼺤äޤ֤Ƥޤ\r\n⤷³ɬפ̵LOCKե뤳ȤǤΥ᡼ʤʤޤ"
#define CLIENT_BODY_4 "ƻ륯饤Ȥ "

#define CLIENT_BODY_5 "饤Ȥ³ޤ "

#define CLIENT_BODY_6 "ѥåȥ¬ "

#define CLIENT_BODY_7 "QUIT ޥɤᡢδƻ륯饤ȤȤ³Ǥޤ "

#define CLIENT_BODY_8 "ƻ륯饤Ȥ "

#define CLIENT_BODY_9 "顼¬ޤ "

#define CLIENT_HEAD_1 "ƻ륯饤ȤȤ̳ǧ "
#define CLIENT_HEAD_2 "ä٤¬ޤ \nƻ륯饤Ȥ˲٤٤ʤ \nͥåȥ˰۾郎̵ǧƤ "


#define CLIENT_HEAD_3 "ʲΥ顼ϴƻ륯饤 "
#define CLIENT_HEAD_4 "ƻ뤷Ƥޤ "

#define CLIENT_HEAD_5 "δƻϴƻ֥å "
#define CLIENT_HEAD_6 "˴ޤޤޤ "

#define CLIENT_HEAD_7 "Υ֥åδƻƸ "
#define CLIENT_HEAD_8 "Υ֥åԽ "

#define CLIENT_HEAD_9 "δƻϡ֥å̾ "
#define CLIENT_HEAD_10 "˴ޤޤޤ "

#define CLIENT_HEAD_11 "ƻ륤󥿡Х䥨顼᡼ϥ֥å꤫Ԥޤ "
#define CLIENT_HEAD_12 "ƻ֥åñ̤¾Υ饤Ȥ˰ư뤳ȤǽǤ "
#define CLIENT_HEAD_13 "饤Υ֥åƸ "
#define CLIENT_HEAD_14 "­ "
#define CLIENT_HEAD_15 "ˤĤƤϡΥ᡼ΰֺǸǧƤ "
#define CLIENT_HEAD_16 "Υ᡼ϥдƻ륷ƥ "
#define CLIENT_HEAD_17 "顼Υ᡼Ǥ "

// 顼᡼


#define MAIL_PR_1 "Ķ⤤׳ǧ"   // 1
#define MAIL_PR_2 "⤤ "              // 2
#define MAIL_PR_3 "㤤 "              // 3 ᡼ʤ


#define MAIL_DATA_1 "ƻܤιԿ¿ᡢƻϳ줬ǽޤ׳ǧ"

#define MAIL_SNMP_11 "-- SNMPƻΥ顼 --"
#define MAIL_SNMP_12 "      : "
#define MAIL_SNMP_13 "        : "
#define MAIL_SNMP_14 "        : "
#define MAIL_SNMP_15 "SNMP OID    : "
#define MAIL_SNMP_16 "ƻ    : "
#define MAIL_SNMP_17 "ƻ  : "
#define MAIL_SNMP_18 "Error   : "

#define MAIL_DHW_11 "-- DHWΥޥɤǥ顼Τޤ --"
#define MAIL_DHW_12 "      : "
#define MAIL_DHW_13 "̿ˡ    : "
#define MAIL_DHW_14 "        : "
#define MAIL_DHW_15 "DHWޥ : "
#define MAIL_DHW_16 "Ԥ    : "
#define MAIL_DHW_17 "ƻ    : "
#define MAIL_DHW_18 "ƻ  : "
#define MAIL_DHW_19 "Error   : "

#define MAIL_DHW_21 "-- DHWޥɤνϤ֤Ƥޤ --"
#define MAIL_DHW_22 "      : "
#define MAIL_DHW_23 "̿ˡ    : "
#define MAIL_DHW_24 "        : "
#define MAIL_DHW_25 "DHWޥ : "
#define MAIL_DHW_26 "Ԥ    : "
#define MAIL_DHW_27 "ƻ    : "
#define MAIL_DHW_28 "ƻ  : "
#define MAIL_DHW_29 "Error   : "

#define MAIL_URL_11 "-- ʲURLޤ --"
#define MAIL_URL_12 "      : "
#define MAIL_URL_13 "̿ˡ    : "
#define MAIL_URL_14 "URL         : "
#define MAIL_URL_15 "ƻݡ  : "
#define MAIL_URL_16 "Ԥ    : "
#define MAIL_URL_17 "ƻ    : "
#define MAIL_URL_18 "ƻ  : "
#define MAIL_URL_19 "Error   : "

#define MAIL_URL_21 "-- ʲURLǽǤ --"
#define MAIL_URL_22 "      : "
#define MAIL_URL_23 "̿ˡ    : "
#define MAIL_URL_24 "URL         : "
#define MAIL_URL_25 "ƻݡ  : "
#define MAIL_URL_26 "Ԥ    : "
#define MAIL_URL_27 "ƻ    : "
#define MAIL_URL_28 "ƻ  : "
#define MAIL_URL_29 "Error   : "

#define MAIL_SMTP_11 "-- ʲSMTPФѽޤ --"
#define MAIL_SMTP_12 "      : "
#define MAIL_SMTP_13 "̿ˡ    : "
#define MAIL_SMTP_14 "SMTP  : "
#define MAIL_SMTP_15 "ƻݡ  : "
#define MAIL_SMTP_16 "Ԥ    : "
#define MAIL_SMTP_17 "ƻ    : "
#define MAIL_SMTP_18 "ƻ  : "
#define MAIL_SMTP_19 "   : "

#define MAIL_SMTP_21 "-- ʲSMTPФѲǽǤ --"
#define MAIL_SMTP_22 "      : "
#define MAIL_SMTP_23 "̿ˡ    : "
#define MAIL_SMTP_24 "SMTP  : "
#define MAIL_SMTP_25 "ƻݡ  : "
#define MAIL_SMTP_26 "Ԥ    : "
#define MAIL_SMTP_27 "ƻ    : "
#define MAIL_SMTP_28 "ƻ  : "
#define MAIL_SMTP_29 "Error   : "

#define MAIL_NTP_11 "-- ʲNTPФȤλֺޤ --"
#define MAIL_NTP_12 "      : "
#define MAIL_NTP_13 "̿ˡ    : "
#define MAIL_NTP_14 "NTP   : "
#define MAIL_NTP_15 "ƻݡ  : "
#define MAIL_NTP_16 "Ԥ    : "
#define MAIL_NTP_17 "ƻ    : "
#define MAIL_NTP_18 "ƻ  : "
#define MAIL_NTP_19 "Error   : "

#define MAIL_NTP_21 "-- ʲNTPФȤλֺϤޤ --"
#define MAIL_NTP_22 "      : "
#define MAIL_NTP_23 "̿ˡ    : "
#define MAIL_NTP_24 "NTP   : "
#define MAIL_NTP_25 "ƻݡ  : "
#define MAIL_NTP_26 "Ԥ    : "
#define MAIL_NTP_27 "ƻ    : "
#define MAIL_NTP_28 "ƻ  : "
#define MAIL_NTP_29 "Error   : "

#define MAIL_PORT_11 "-- ʲΥݡȤĤƤޤ --"
#define MAIL_PORT_12 "      : "
#define MAIL_PORT_13 "̿ˡ    : "
#define MAIL_PORT_14 "        : "
#define MAIL_PORT_15 "ƻݡ  : "
#define MAIL_PORT_16 "Ԥ    : "
#define MAIL_PORT_17 "ƻ    : "
#define MAIL_PORT_18 "ƻ  : "
#define MAIL_PORT_19 "Error   : "

#define MAIL_PORT_21 "-- ʲΥݡȤƤޤ --"
#define MAIL_PORT_22 "      : "
#define MAIL_PORT_23 "̿ˡ    : "
#define MAIL_PORT_24 "        : "
#define MAIL_PORT_25 "ƻݡ  : "
#define MAIL_PORT_26 "Ԥ    : "
#define MAIL_PORT_27 "ƻ    : "
#define MAIL_PORT_28 "ƻ  : "
#define MAIL_PORT_29 "Error   : "

#define MAIL_COMMAND_11 "-- ʲΥޥɤ顼֤Ƥޤ --"
#define MAIL_COMMAND_12 "       : "
#define MAIL_COMMAND_13 "¹ԥޥ : "
#define MAIL_COMMAND_14 "Ԥ     : "
#define MAIL_COMMAND_15 "ƻ     : "
#define MAIL_COMMAND_16 "ƻ   : "
#define MAIL_COMMAND_17 "Error    : "

#define MAIL_COMMAND_21 "-- ޥɤϤ֤Ƥޤ --"
#define MAIL_COMMAND_22 "       : "
#define MAIL_COMMAND_23 "¹ԥޥ : "
#define MAIL_COMMAND_24 "Ԥ     : "
#define MAIL_COMMAND_25 "ƻ     : "
#define MAIL_COMMAND_26 "ƻ   : "
#define MAIL_COMMAND_27 "Error    : "

#define MONITOR_ID      "ƻֹ    : " 
#define MONITOR_SER     "ƻԽ    : " 


#define MAIL_CTL_1     "ٹ "
#define MAIL_CTL_2     "Zither ƻ륵мΤߤƤޤΥ᡼zitherctlƤޤ "
#define MAIL_CTL_3     "ZitherߤƤ硢۲δƻƹԤƤޤ "




#endif

==> zither-1.1.17.tar.gz: zither_prj/zither/jpreturn.h <==
// jpreturn.h
// $Id: jpreturn.h,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
// masashi shimakura
//
//
// japanese code return file. jpreturn.h
// 
// Υեjpretun.hˤϡsitar(biwa)Фܸ᤹ʸdefineʬܤƤޤ
// ɬ EUC-JP Υ󥳡ǥ󥰤¸Ƥ
// Windows(VC++)ξϲƤޤޤǤ
// 

#ifndef _JPRETURN_H_
  #define _JPRETURN_H_
  
#define MAIL_BODY_1 "Υ֥åϥ᡼ˡưַ⡼1ꤵƤޤ \n ⤦ĥ顼Ϣ³ߤޤ \n üߤȡˤʴƻ뤬3Ϣ³ƹԤɬפޤ\n\n\n"
#define MAIL_BODY_2 "Υ֥åϥ᡼ˡưַ⡼2ꤵƤޤ \n ⤦ĥ顼Ϣ³ߤޤ \n üߤȡˤʴƻ뤬Ԥɬפޤ\n\n\n"

#define ADMIN_BODY_1 "Administratorޥzitherδѹǽޤ\n̵꤬Τ륤餫⤷ޤ \r\nǰΤᡢôԤ˳ǧƤߤƤ  "

#define ADMIN_BODY_2 "ưѹԤޤ "

#define CLIENT_BODY_1  "ƻ륯饤ȤȤ³ޤ\nΰդ̵Хȥ֥βǽޤ \n δƻ륯饤ȤǼ¹ԤƤƻϡƼ¹ԤƤޤ "
#define CLIENT_BODY_2 "饤Ȥ³ڤޤ "

#define CLIENT_BODY_3 "zitherФ˲³sitarƻ륯饤Ȥ³򼺤äޤ֤Ƥޤ\n⤷³ɬפ̵LOCKե뤳ȤǤΥ᡼ʤʤޤ "
#define CLIENT_BODY_4 "ƻ륯饤Ȥ Ǥ"

#define CLIENT_BODY_5 "饤Ȥ³ޤ "

#define CLIENT_BODY_6 "sitarȤ³˥ѥåȥ¬ޤ "

#define CLIENT_BODY_7 "QUIT ޥɤᡢδƻ륯饤ȤȤ³Ǥޤ "

#define CLIENT_BODY_8 "ƻ륯饤Ȥ "

// #define CLIENT_BODY_9 "顼¬ޤ "
#define CLIENT_BODY_9 "ƻǥ顼¬ޤ "

#define CLIENT_BODY_10 "顼¬ޤΤǡʲδƻƤǧƤ  "

#define CLIENT_BODY_11 "ǡ١˽񤭹ޤƤʤǽޤ\nǧƤ\nɬפʤƵưƤ  "


#define CLIENT_BODY_12 "ǡ١³ǤƤޤ  "

#define CLIENT_BODY_13 "ƻܤԽϰʲURLԤȤǤޤ "

#define CLIENT_HEAD_1 "ƻ륯饤ȤȤ̳ǧ "
#define CLIENT_HEAD_2 "ä٤¬ޤ \nƻ륯饤Ȥ˲٤٤ʤ \nͥåȥ˰۾郎̵ǧƤ "


#define CLIENT_HEAD_3 "ʲΥ顼ϴƻ륯饤 "
#define CLIENT_HEAD_4 "ƻ뤷Ƥޤ "

#define CLIENT_HEAD_5 "δƻϴƻ֥å "
#define CLIENT_HEAD_6 "˴ޤޤޤ "

#define CLIENT_HEAD_7 "Υ֥åδƻƸ "
#define CLIENT_HEAD_8 "Υ֥åԽ "

#define CLIENT_HEAD_9 "δƻϡ֥å̾ "
#define CLIENT_HEAD_10 "˴ޤޤޤ "

#define CLIENT_HEAD_11 "ƻ륤󥿡Х䥨顼᡼ϥ֥å꤫Ԥޤ "
#define CLIENT_HEAD_12 "ƻ֥åñ̤¾Υ饤Ȥ˰ư뤳ȤǽǤ "
#define CLIENT_HEAD_13 "饤Υ֥åƸ "
#define CLIENT_HEAD_14 "­ "
#define CLIENT_HEAD_15 "ˤĤƤϡΥ᡼ΰֺǸǧƤ "
#define CLIENT_HEAD_16 "Υ᡼ϥдƻ륷ƥ "
#define CLIENT_HEAD_17 "顼Υ᡼Ǥ "

// 顼᡼


#define MAIL_PR_1 " "                // 1
#define MAIL_PR_2 " "                // 2
#define MAIL_PR_3 " "                // 3 ᡼ʤ


#define MAIL_DATA_1 "ƻܤιԿ¿ᡢƻϳ줬ǽޤ׳ǧ"

#define MAIL_SNMP_11 "-- SNMPƻΥ顼 --"
#define MAIL_SNMP_12 "      : "
#define MAIL_SNMP_13 "        : "
#define MAIL_SNMP_14 "ۥ̾    : " 
#define MAIL_SNMP_15 "SNMP OID    : "
#define MAIL_SNMP_16 "ƻ    : "
#define MAIL_SNMP_17 "ƻ  : "
#define MAIL_SNMP_18 "Error   : "

#define MAIL_DHW_11 "-- DHWΥޥɤǥ顼Τޤ --"
#define MAIL_DHW_12 "      : "
#define MAIL_DHW_13 "ץȥ  : "
#define MAIL_DHW_14 "ۥ̾    : " 
#define MAIL_DHW_15 "DHWޥ : "
#define MAIL_DHW_16 "Ԥ    : "
#define MAIL_DHW_17 "ƻ    : "
#define MAIL_DHW_18 "ƻ  : "
#define MAIL_DHW_19 "Error   : "

#define MAIL_DHW_21 "-- DHWޥɤνϤ֤Ƥޤ --"
#define MAIL_DHW_22 "      : "
#define MAIL_DHW_23 "ץȥ  : "
#define MAIL_DHW_24 "ۥ̾    : " 
#define MAIL_DHW_25 "DHWޥ : "
#define MAIL_DHW_26 "Ԥ    : "
#define MAIL_DHW_27 "ƻ    : "
#define MAIL_DHW_28 "ƻ  : "
#define MAIL_DHW_29 "Error   : "

#define MAIL_URL_11 "-- ʲURLޤ --"
#define MAIL_URL_12 "      : "
#define MAIL_URL_13 "ץȥ  : "
#define MAIL_URL_14 "URL         : "
#define MAIL_URL_15 "ƻݡ  : "
#define MAIL_URL_16 "Ԥ    : "
#define MAIL_URL_17 "ƻ    : "
#define MAIL_URL_18 "ƻ  : "
#define MAIL_URL_19 "Error   : "

#define MAIL_URL_21 "-- ʲURLǽǤ --"
#define MAIL_URL_22 "      : "
#define MAIL_URL_23 "ץȥ  : "
#define MAIL_URL_24 "URL         : "
#define MAIL_URL_25 "ƻݡ  : "
#define MAIL_URL_26 "Ԥ    : "
#define MAIL_URL_27 "ƻ    : "
#define MAIL_URL_28 "ƻ  : "
#define MAIL_URL_29 "Error   : "

#define MAIL_SMTP_11 "-- ʲSMTPФѽޤ --"
#define MAIL_SMTP_12 "      : "
#define MAIL_SMTP_13 "ץȥ  : "
#define MAIL_SMTP_14 "SMTP  : "
#define MAIL_SMTP_15 "ƻݡ  : "
#define MAIL_SMTP_16 "Ԥ    : "
#define MAIL_SMTP_17 "ƻ    : "
#define MAIL_SMTP_18 "ƻ  : "
#define MAIL_SMTP_19 "   : "

#define MAIL_SMTP_21 "-- ʲSMTPФѲǽǤ --"
#define MAIL_SMTP_22 "      : "
#define MAIL_SMTP_23 "ץȥ  : "
#define MAIL_SMTP_24 "SMTP  : "
#define MAIL_SMTP_25 "ƻݡ  : "
#define MAIL_SMTP_26 "Ԥ    : "
#define MAIL_SMTP_27 "ƻ    : "
#define MAIL_SMTP_28 "ƻ  : "
#define MAIL_SMTP_29 "Error   : "

#define MAIL_NTP_11 "-- ʲNTPФȤλֺޤ --"
#define MAIL_NTP_12 "      : "
#define MAIL_NTP_13 "ץȥ  : "
#define MAIL_NTP_14 "NTP   : "
#define MAIL_NTP_15 "ƻݡ  : "
#define MAIL_NTP_16 "Ԥ    : "
#define MAIL_NTP_17 "ƻ    : "
#define MAIL_NTP_18 "ƻ  : "
#define MAIL_NTP_19 "Error   : "

#define MAIL_NTP_21 "-- ʲNTPФȤλֺϤޤ --"
#define MAIL_NTP_22 "      : "
#define MAIL_NTP_23 "ץȥ  : "
#define MAIL_NTP_24 "NTP   : "
#define MAIL_NTP_25 "ƻݡ  : "
#define MAIL_NTP_26 "Ԥ    : "
#define MAIL_NTP_27 "ƻ    : "
#define MAIL_NTP_28 "ƻ  : "
#define MAIL_NTP_29 "Error   : "

#define MAIL_PORT_11 "-- ʲΥݡȤĤƤޤ --"
#define MAIL_PORT_12 "      : "
#define MAIL_PORT_13 "ץȥ  : "
#define MAIL_PORT_14 "ۥ̾    : " 
#define MAIL_PORT_15 "ƻݡ  : "
#define MAIL_PORT_16 "Ԥ    : "
#define MAIL_PORT_17 "ƻ    : "
#define MAIL_PORT_18 "ƻ  : "
#define MAIL_PORT_19 "Error   : "

#define MAIL_PORT_21 "-- ʲΥݡȤƤޤ --"
#define MAIL_PORT_22 "      : "
#define MAIL_PORT_23 "ץȥ  : "
#define MAIL_PORT_24 "ۥ̾    : " 
#define MAIL_PORT_25 "ƻݡ  : "
#define MAIL_PORT_26 "Ԥ    : "
#define MAIL_PORT_27 "ƻ    : "
#define MAIL_PORT_28 "ƻ  : "
#define MAIL_PORT_29 "Error   : "

#define MAIL_COMMAND_11 "-- ʲΥޥɤ顼֤Ƥޤ --"
#define MAIL_COMMAND_12 "       : "
#define MAIL_COMMAND_13 "¹ԥޥ : "
#define MAIL_COMMAND_14 "Ԥ     : "
#define MAIL_COMMAND_15 "ƻ     : "
#define MAIL_COMMAND_16 "ƻ   : "
#define MAIL_COMMAND_17 "Error    : "

#define MAIL_COMMAND_21 "-- ޥɤϤ֤Ƥޤ --"
#define MAIL_COMMAND_22 "       : "
#define MAIL_COMMAND_23 "¹ԥޥ : "
#define MAIL_COMMAND_24 "Ԥ     : "
#define MAIL_COMMAND_25 "ƻ     : "
#define MAIL_COMMAND_26 "ƻ   : "
#define MAIL_COMMAND_27 "Error    : "

#define MONITOR_ID      "ƻֹ    : " 
#define MONITOR_SER     "ƻǧ    : " 


#define MAIL_CTL_1     "ٹ "
#define MAIL_CTL_2     "Zither ƻ륵мΤߤƤޤΥ᡼zitherctlƤޤ "
#define MAIL_CTL_3     "ZitherߤƤ硢۲δƻƹԤƤޤ "



#endif
